TaggedWave-class: A S4 class for tagged waves

TaggedWave-classR Documentation

A S4 class for tagged waves

Description

The TaggedWave class extended the Wave class from the tuneR package so that it can include extended metadata and the results of analyses.

Slots

metadata

A list for storing metadata.

analyses

A list for storing analyses.


sonicscrewdriver documentation built on Aug. 21, 2026, 5:15 p.m.