channels_se: Channels for sound ecology

View source: R/allChannels.R

channels_seR Documentation

Channels for sound ecology

Description

Used to process the output of acoustic index functions from the soundecology package when using allChannels.

Usage

channels_se(...)

Arguments

...

Export from a bioacoustic index function from the soundecology package


sonicscrewdriver documentation built on Aug. 21, 2026, 5:15 p.m.