jitter: Calculate the jitter in a Wave object

View source: R/jitter.R

jitterR Documentation

Calculate the jitter in a Wave object

Description

Jitter is a measure of the variability of periods in the waveform. Relative jitter is scaled by the jitter in the analysed waveform.

Usage

jitter(wave, method = "absolute")

Arguments

wave

A Wave object

method

One of "absolute" or "relative"

Value

A vector of zero crossing locations

Examples

## Not run: 
jitter(sheep, method="absolute")
jitter(sheep, method="relative")

## End(Not run)

sonicscrewdriver documentation built on Aug. 21, 2026, 5:15 p.m.